CCL: /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_background.h Source File

CCL

ccl_background.h
Go to the documentation of this file.
1
3 #pragma once
4 #include "ccl_core.h"
5
6 //Omega_x labels
7 typedef enum ccl_omega_x_label {
8 ccl_omega_m_label=0,
9 ccl_omega_l_label=1,
10 ccl_omega_g_label=2,
11 ccl_omega_k_label=3,
12 ccl_omega_ur_label=4,
13 ccl_omega_nu_label=5
14 } ccl_omega_x_label;
15
25 double ccl_h_over_h0(ccl_cosmology * cosmo, double a, int * status);
26
38 void ccl_h_over_h0s(ccl_cosmology * cosmo, int na, double a[na], double output[na], int * status);
39
48 double ccl_comoving_radial_distance(ccl_cosmology * cosmo, double a, int* status);
49
61 void ccl_comoving_radial_distances(ccl_cosmology * cosmo, int na, double a[na], double output[na], int* status);
62
75 double ccl_sinn(ccl_cosmology *cosmo,double chi, int *status);
76
87 double ccl_comoving_angular_distance(ccl_cosmology * cosmo, double a, int* status);
88
102 void ccl_comoving_angular_distances(ccl_cosmology * cosmo, int na, double a[na], double output[na], int* status);
103
112 double ccl_luminosity_distance(ccl_cosmology * cosmo, double a, int * status);
113
125 void ccl_luminosity_distances(ccl_cosmology * cosmo, int na, double a[na], double output[na], int * status);
126
135 double ccl_distance_modulus(ccl_cosmology * cosmo, double a, int * status);
136
148 void ccl_distance_moduli(ccl_cosmology * cosmo, int na, double a[na], double output[na], int * status);
149
150
159 double ccl_growth_factor(ccl_cosmology * cosmo, double a, int * status);
160
172 void ccl_growth_factors(ccl_cosmology * cosmo, int na, double a[na], double output[na], int * status);
173
174 //
183 double ccl_growth_factor_unnorm(ccl_cosmology * cosmo, double a, int * status);
184
196 void ccl_growth_factors_unnorm(ccl_cosmology * cosmo, int na, double a[na], double output[na], int * status);
197
206 double ccl_growth_rate(ccl_cosmology * cosmo, double a, int* status);
207
219 void ccl_growth_rates(ccl_cosmology * cosmo, int na, double a[na], double output[na], int * status);
220
229 double ccl_scale_factor_of_chi(ccl_cosmology * cosmo, double chi, int * status);
230
242 void ccl_scale_factor_of_chis(ccl_cosmology * cosmo, int nchi, double chi[nchi], double output[nchi], int* status);
243
253 double ccl_omega_x(ccl_cosmology * cosmo, double a, ccl_omega_x_label label, int* status);
ccl_scale_factor_of_chi
double ccl_scale_factor_of_chi(ccl_cosmology *cosmo, double chi, int *status)
Definition: ccl_background.c:824
ccl_distance_moduli
void ccl_distance_moduli(ccl_cosmology *cosmo, int na, double a[na], double output[na], int *status)
Definition: ccl_background.c:802
ccl_h_over_h0
double ccl_h_over_h0(ccl_cosmology *cosmo, double a, int *status)
Definition: ccl_background.c:622
ccl_omega_k_label
Definition: ccl_background.h:11
ccl_growth_factor
double ccl_growth_factor(ccl_cosmology *cosmo, double a, int *status)
Definition: ccl_background.c:859
ccl_luminosity_distance
double ccl_luminosity_distance(ccl_cosmology *cosmo, double a, int *status)
Definition: ccl_background.c:744
ccl_growth_factor_unnorm
double ccl_growth_factor_unnorm(ccl_cosmology *cosmo, double a, int *status)
Definition: ccl_background.c:891
ccl_core.h
ccl_growth_rate
double ccl_growth_rate(ccl_cosmology *cosmo, double a, int *status)
Definition: ccl_background.c:922
ccl_comoving_angular_distance
double ccl_comoving_angular_distance(ccl_cosmology *cosmo, double a, int *status)
Definition: ccl_background.c:699
ccl_omega_x
double ccl_omega_x(ccl_cosmology *cosmo, double a, ccl_omega_x_label label, int *status)
Definition: ccl_background.c:50
ccl_scale_factor_of_chis
void ccl_scale_factor_of_chis(ccl_cosmology *cosmo, int nchi, double chi[nchi], double output[nchi], int *status)
Definition: ccl_background.c:843
ccl_comoving_angular_distances
void ccl_comoving_angular_distances(ccl_cosmology *cosmo, int na, double a[na], double output[na], int *status)
Definition: ccl_background.c:721
ccl_sinn
double ccl_sinn(ccl_cosmology *cosmo, double chi, int *status)
Definition: ccl_background.c:679
ccl_omega_nu_label
Definition: ccl_background.h:13
ccl_growth_factors
void ccl_growth_factors(ccl_cosmology *cosmo, int na, double a[na], double output[na], int *status)
Definition: ccl_background.c:875
ccl_omega_x_label
ccl_omega_x_label
Definition: ccl_background.h:7
ccl_growth_rates
void ccl_growth_rates(ccl_cosmology *cosmo, int na, double a[na], double output[na], int *status)
Definition: ccl_background.c:938
ccl_h_over_h0s
void ccl_h_over_h0s(ccl_cosmology *cosmo, int na, double a[na], double output[na], int *status)
Definition: ccl_background.c:632
ccl_omega_m_label
Definition: ccl_background.h:8
ccl_comoving_radial_distances
void ccl_comoving_radial_distances(ccl_cosmology *cosmo, int na, double a[na], double output[na], int *status)
Definition: ccl_background.c:662
ccl_omega_l_label
Definition: ccl_background.h:9
ccl_growth_factors_unnorm
void ccl_growth_factors_unnorm(ccl_cosmology *cosmo, int na, double a[na], double output[na], int *status)
Definition: ccl_background.c:907
ccl_cosmology
Definition: ccl_core.h:115
ccl_omega_g_label
Definition: ccl_background.h:10
ccl_distance_modulus
double ccl_distance_modulus(ccl_cosmology *cosmo, double a, int *status)
Definition: ccl_background.c:778
ccl_comoving_radial_distance
double ccl_comoving_radial_distance(ccl_cosmology *cosmo, double a, int *status)
Definition: ccl_background.c:644
ccl_omega_ur_label
Definition: ccl_background.h:12
ccl_luminosity_distances
void ccl_luminosity_distances(ccl_cosmology *cosmo, int na, double a[na], double output[na], int *status)
Definition: ccl_background.c:762